@@ -35,6 +35,7 @@ def extract_corpus_text(
     dehyphen: bool = False,
     data_path: str = '.',
     compress_type: dispatch.CompressType = dispatch.CompressType.Zip,
+    branch: str = 'main',
     **_,
 ) -> None:
     """Group extracted protocol blocks by `temporal_key` and attribute `group_keys`.
@@ -63,7 +64,7 @@ def extract_corpus_text(
         source_folder=source_folder, source_pattern='**/prot-*.xml', years=years
     )
     member_index: member.ParliamentaryMemberIndex = member.ParliamentaryMemberIndex(
-        source_folder=f'{source_folder}', branch='dev'
+        source_folder=f'{source_folder}', branch=branch
     )
 
     preprocessor: Callable[[str], str] = utility.compose(
